@@ -16,6 +16,7 @@ from jsw_nx.base.map import map
 from jsw_nx.base.mix import mix
 from jsw_nx.base.reduce import reduce
 from jsw_nx.base.set import set
+from jsw_nx.base.type import type
 
 # ruby style
 from jsw_nx.rubify.times import times
@@ -28,9 +29,11 @@ from jsw_nx.rubify.to_s import to_s
 
 # next packages
 from jsw_nx.packages.days import days
+from jsw_nx.packages.tmpl import tmpl
 
 # next classes
 from jsw_nx.classes.date import Date
 from jsw_nx.classes.fileutils import FileUtils as fileutils
 from jsw_nx.classes.tar import Tar as tar
 from jsw_nx.classes.json import JSON
+from jsw_nx.classes.ymd import Ymd
